@@ -106,6 +106,17 @@ for each specific article; to parse a comprehensive dump file use the Parse::Med
     print "title '", $page->title, "' id ", $page->id, "\n";
   }
 
+=head1 STATUS
+
+=head1 STATUS
+
+This software is being RETIRED - MediaWiki::DumpFile is the official successor to
+Parse::MediaWikiDump and includes a compatibility library called MediaWiki::DumpFile::Compat
+that is 100% API compatible and is a near perfect standin for this module. It is faster
+in all instances where it counts and is actively maintained. Any undocumented deviation
+of MediaWiki::DumpFile::Compat from Parse::MediaWikiDump is considered a bug and will
+be fixed. 
+
 =head1 METHODS
 
 =over 4
