@@ -36,6 +36,15 @@ Parse::MediaWikiDump::link - Object representing a link from one article to anot
 
 This object is used to access the data associated with each individual link between articles in a MediaWiki instance. 
 
+=head1 STATUS
+
+This software is being RETIRED - MediaWiki::DumpFile is the official successor to
+Parse::MediaWikiDump and includes a compatibility library called MediaWiki::DumpFile::Compat
+that is 100% API compatible and is a near perfect standin for this module. It is faster
+in all instances where it counts and is actively maintained. Any undocumented deviation
+of MediaWiki::DumpFile::Compat from Parse::MediaWikiDump is considered a bug and will
+be fixed. 
+
 =head1 METHODS
 
 =over 4
